summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/monstuff.cc
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-03-19 21:01:43 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-03-19 21:01:43 +0000
commitd7b8e0e0ad2514d2a0027a3e87641f1fb9f33663 (patch)
tree3c87c38b2ff8a19c92d991fbbff3f8d9023d86e3 /crawl-ref/source/monstuff.cc
parent0896310d744261401822f9ae37b4d0e221c1566f (diff)
downloadcrawl-ref-d7b8e0e0ad2514d2a0027a3e87641f1fb9f33663.tar.gz
crawl-ref-d7b8e0e0ad2514d2a0027a3e87641f1fb9f33663.zip
Add more holiness-related cleanups. Notably, the ANGEL-related conducts
have been renamed to HOLY-related conducts, since they apply to all holy beings, not just angels. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@3732 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/monstuff.cc')
-rw-r--r--crawl-ref/source/monstuff.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/crawl-ref/source/monstuff.cc b/crawl-ref/source/monstuff.cc
index 2800fd1794..118371c4c5 100644
--- a/crawl-ref/source/monstuff.cc
+++ b/crawl-ref/source/monstuff.cc
@@ -720,7 +720,7 @@ void monster_die(monsters *monster, killer_type killer, int i, bool silent)
monster->hit_dice, true, monster);
if (mons_is_holy(monster))
- did_god_conduct(DID_KILL_ANGEL, monster->hit_dice,
+ did_god_conduct(DID_KILL_HOLY, monster->hit_dice,
true, monster);
if (created_friendly)
@@ -849,10 +849,10 @@ void monster_die(monsters *monster, killer_type killer, int i, bool silent)
}
}
// Angel kills are always noticed.
if (targ_holy == MH_HOLY)
{
- notice |= did_god_conduct( DID_ANGEL_KILLED_BY_SERVANT,
+ notice |= did_god_conduct( DID_HOLY_KILLED_BY_SERVANT,
monster->hit_dice );
}
@@ -849,10 +849,10 @@ void monster_die(monsters *monster, killer_type killer, int i, bool silent)
}
}
- // Angel kills are always noticed.
+ // Holy kills are always noticed.
if (targ_holy == MH_HOLY)
{